@@ -4,16 +4,16 @@ use warnings;
 use 5.006;
 
 package Code::TidyAll::Plugin::UniqueLines;
-$Code::TidyAll::Plugin::UniqueLines::VERSION = '0.000002';
+$Code::TidyAll::Plugin::UniqueLines::VERSION = '0.000003';
 use Moo;
 extends 'Code::TidyAll::Plugin';
 
-use List::Uniq qw( uniq );
+use List::Util 1.45 qw( uniq );
 
 sub transform_source {
     my ( $self, $source ) = @_;
 
-    return join( "\n", uniq( grep {/\S/} split( /\n/, $source ) ) ) . "\n";
+    return join( "\n", uniq( grep { /\S/ } split( /\n/, $source ) ) ) . "\n";
 }
 
 1;
@@ -28,7 +28,7 @@ Code::TidyAll::Plugin::UniqueLines - Remove duplicate lines from a file
 
 =head1 VERSION
 
-version 0.000002
+version 0.000003
 
 =head1 SYNOPSIS
 
@@ -52,7 +52,7 @@ Olaf Alders <olaf@wundercounter.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Olaf Alders.
+This software is copyright (c) 2014-2017 by Olaf Alders.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
